import typing

import typing_extensions

_list = list

@typing.type_check_only
class Blog(typing_extensions.TypedDict, total=False):
    customMetaData: str
    description: str
    id: str
    kind: str
    locale: dict[str, typing.Any]
    name: str
    pages: dict[str, typing.Any]
    posts: dict[str, typing.Any]
    published: str
    selfLink: str
    status: typing_extensions.Literal["LIVE", "DELETED"]
    updated: str
    url: str

@typing.type_check_only
class BlogList(typing_extensions.TypedDict, total=False):
    blogUserInfos: _list[BlogUserInfo]
    items: _list[Blog]
    kind: str

@typing.type_check_only
class BlogPerUserInfo(typing_extensions.TypedDict, total=False):
    blogId: str
    hasAdminAccess: bool
    kind: str
    photosAlbumKey: str
    role: typing_extensions.Literal[
        "VIEW_TYPE_UNSPECIFIED", "READER", "AUTHOR", "ADMIN"
    ]
    userId: str

@typing.type_check_only
class BlogUserInfo(typing_extensions.TypedDict, total=False):
    blog: Blog
    blog_user_info: BlogPerUserInfo
    kind: str

@typing.type_check_only
class Comment(typing_extensions.TypedDict, total=False):
    author: dict[str, typing.Any]
    blog: dict[str, typing.Any]
    content: str
    id: str
    inReplyTo: dict[str, typing.Any]
    kind: str
    post: dict[str, typing.Any]
    published: str
    selfLink: str
    status: typing_extensions.Literal["LIVE", "EMPTIED", "PENDING", "SPAM"]
    updated: str

@typing.type_check_only
class CommentList(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Comment]
    kind: str
    nextPageToken: str
    prevPageToken: str

@typing.type_check_only
class Page(typing_extensions.TypedDict, total=False):
    author: dict[str, typing.Any]
    blog: dict[str, typing.Any]
    content: str
    etag: str
    id: str
    kind: str
    published: str
    selfLink: str
    status: typing_extensions.Literal["LIVE", "DRAFT", "SOFT_TRASHED"]
    title: str
    trashed: str
    updated: str
    url: str

@typing.type_check_only
class PageList(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Page]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Pageviews(typing_extensions.TypedDict, total=False):
    blogId: str
    counts: _list[dict[str, typing.Any]]
    kind: str

@typing.type_check_only
class Post(typing_extensions.TypedDict, total=False):
    author: dict[str, typing.Any]
    blog: dict[str, typing.Any]
    content: str
    customMetaData: str
    etag: str
    id: str
    images: _list[dict[str, typing.Any]]
    kind: str
    labels: _list[str]
    location: dict[str, typing.Any]
    published: str
    readerComments: typing_extensions.Literal[
        "ALLOW", "DONT_ALLOW_SHOW_EXISTING", "DONT_ALLOW_HIDE_EXISTING"
    ]
    replies: dict[str, typing.Any]
    selfLink: str
    status: typing_extensions.Literal["LIVE", "DRAFT", "SCHEDULED", "SOFT_TRASHED"]
    title: str
    titleLink: str
    trashed: str
    updated: str
    url: str

@typing.type_check_only
class PostList(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Post]
    kind: str
    nextPageToken: str
    prevPageToken: str

@typing.type_check_only
class PostPerUserInfo(typing_extensions.TypedDict, total=False):
    blogId: str
    hasEditAccess: bool
    kind: str
    postId: str
    userId: str

@typing.type_check_only
class PostUserInfo(typing_extensions.TypedDict, total=False):
    kind: str
    post: Post
    post_user_info: PostPerUserInfo

@typing.type_check_only
class PostUserInfosList(typing_extensions.TypedDict, total=False):
    items: _list[PostUserInfo]
    kind: str
    nextPageToken: str

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    about: str
    blogs: dict[str, typing.Any]
    created: str
    displayName: str
    id: str
    kind: str
    locale: dict[str, typing.Any]
    selfLink: str
    url: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class BigQueryOptions(typing_extensions.TypedDict, total=False):
    usePartitionedTables: bool
    usesTimestampColumnPartitioning: bool

@typing.type_check_only
class BucketOptions(typing_extensions.TypedDict, total=False):
    explicitBuckets: Explicit
    exponentialBuckets: Exponential
    linearBuckets: Linear

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CmekSettings(typing_extensions.TypedDict, total=False):
    kmsKeyName: str
    kmsKeyVersionName: str
    name: str
    serviceAccountId: str

@typing.type_check_only
class CopyLogEntriesMetadata(typing_extensions.TypedDict, total=False):
    cancellationRequested: bool
    endTime: str
    progress: int
    request: CopyLogEntriesRequest
    startTime: str
    state: typing_extensions.Literal[
        "OPERATION_STATE_UNSPECIFIED",
        "OPERATION_STATE_SCHEDULED",
        "OPERATION_STATE_WAITING_FOR_PERMISSIONS",
        "OPERATION_STATE_RUNNING",
        "OPERATION_STATE_SUCCEEDED",
        "OPERATION_STATE_FAILED",
        "OPERATION_STATE_CANCELLED",
    ]
    writerIdentity: str

@typing.type_check_only
class CopyLogEntriesRequest(typing_extensions.TypedDict, total=False):
    destination: str
    filter: str
    name: str

@typing.type_check_only
class CopyLogEntriesResponse(typing_extensions.TypedDict, total=False):
    logEntriesCopiedCount: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Explicit(typing_extensions.TypedDict, total=False):
    bounds: _list[float]

@typing.type_check_only
class Exponential(typing_extensions.TypedDict, total=False):
    growthFactor: float
    numFiniteBuckets: int
    scale: float

@typing.type_check_only
class HttpRequest(typing_extensions.TypedDict, total=False):
    cacheFillBytes: str
    cacheHit: bool
    cacheLookup: bool
    cacheValidatedWithOriginServer: bool
    latency: str
    protocol: str
    referer: str
    remoteIp: str
    requestMethod: str
    requestSize: str
    requestUrl: str
    responseSize: str
    serverIp: str
    status: int
    userAgent: str

@typing.type_check_only
class IndexConfig(typing_extensions.TypedDict, total=False):
    createTime: str
    fieldPath: str
    type: typing_extensions.Literal[
        "INDEX_TYPE_UNSPECIFIED", "INDEX_TYPE_STRING", "INDEX_TYPE_INTEGER"
    ]

@typing.type_check_only
class LabelDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    key: str
    valueType: typing_extensions.Literal["STRING", "BOOL", "INT64"]

@typing.type_check_only
class Linear(typing_extensions.TypedDict, total=False):
    numFiniteBuckets: int
    offset: float
    width: float

@typing.type_check_only
class ListBucketsResponse(typing_extensions.TypedDict, total=False):
    buckets: _list[LogBucket]
    nextPageToken: str

@typing.type_check_only
class ListExclusionsResponse(typing_extensions.TypedDict, total=False):
    exclusions: _list[LogExclusion]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListLogEntriesRequest(typing_extensions.TypedDict, total=False):
    filter: str
    orderBy: str
    pageSize: int
    pageToken: str
    projectIds: _list[str]
    resourceNames: _list[str]

@typing.type_check_only
class ListLogEntriesResponse(typing_extensions.TypedDict, total=False):
    entries: _list[LogEntry]
    nextPageToken: str

@typing.type_check_only
class ListLogMetricsResponse(typing_extensions.TypedDict, total=False):
    metrics: _list[LogMetric]
    nextPageToken: str

@typing.type_check_only
class ListLogsResponse(typing_extensions.TypedDict, total=False):
    logNames: _list[str]
    nextPageToken: str

@typing.type_check_only
class ListMonitoredResourceDescriptorsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    resourceDescriptors: _list[MonitoredResourceDescriptor]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListSinksResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    sinks: _list[LogSink]

@typing.type_check_only
class ListViewsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    views: _list[LogView]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class LogBucket(typing_extensions.TypedDict, total=False):
    cmekSettings: CmekSettings
    createTime: str
    description: str
    indexConfigs: _list[IndexConfig]
    lifecycleState: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED", "ACTIVE", "DELETE_REQUESTED"
    ]
    locked: bool
    name: str
    restrictedFields: _list[str]
    retentionDays: int
    updateTime: str

@typing.type_check_only
class LogEntry(typing_extensions.TypedDict, total=False):
    httpRequest: HttpRequest
    insertId: str
    jsonPayload: dict[str, typing.Any]
    labels: dict[str, typing.Any]
    logName: str
    metadata: MonitoredResourceMetadata
    operation: LogEntryOperation
    protoPayload: dict[str, typing.Any]
    receiveTimestamp: str
    resource: MonitoredResource
    severity: typing_extensions.Literal[
        "DEFAULT",
        "DEBUG",
        "INFO",
        "NOTICE",
        "WARNING",
        "ERROR",
        "CRITICAL",
        "ALERT",
        "EMERGENCY",
    ]
    sourceLocation: LogEntrySourceLocation
    spanId: str
    split: LogSplit
    textPayload: str
    timestamp: str
    trace: str
    traceSampled: bool

@typing.type_check_only
class LogEntryOperation(typing_extensions.TypedDict, total=False):
    first: bool
    id: str
    last: bool
    producer: str

@typing.type_check_only
class LogEntrySourceLocation(typing_extensions.TypedDict, total=False):
    file: str
    function: str
    line: str

@typing.type_check_only
class LogExclusion(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    disabled: bool
    filter: str
    name: str
    updateTime: str

@typing.type_check_only
class LogLine(typing_extensions.TypedDict, total=False):
    logMessage: str
    severity: typing_extensions.Literal[
        "DEFAULT",
        "DEBUG",
        "INFO",
        "NOTICE",
        "WARNING",
        "ERROR",
        "CRITICAL",
        "ALERT",
        "EMERGENCY",
    ]
    sourceLocation: SourceLocation
    time: str

@typing.type_check_only
class LogMetric(typing_extensions.TypedDict, total=False):
    bucketName: str
    bucketOptions: BucketOptions
    createTime: str
    description: str
    disabled: bool
    filter: str
    labelExtractors: dict[str, typing.Any]
    metricDescriptor: MetricDescriptor
    name: str
    updateTime: str
    valueExtractor: str
    version: typing_extensions.Literal["V2", "V1"]

@typing.type_check_only
class LogSink(typing_extensions.TypedDict, total=False):
    bigqueryOptions: BigQueryOptions
    createTime: str
    description: str
    destination: str
    disabled: bool
    exclusions: _list[LogExclusion]
    filter: str
    includeChildren: bool
    name: str
    outputVersionFormat: typing_extensions.Literal[
        "VERSION_FORMAT_UNSPECIFIED", "V2", "V1"
    ]
    updateTime: str
    writerIdentity: str

@typing.type_check_only
class LogSplit(typing_extensions.TypedDict, total=False):
    index: int
    totalSplits: int
    uid: str

@typing.type_check_only
class LogView(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    filter: str
    name: str
    updateTime: str

@typing.type_check_only
class MetricDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    metadata: MetricDescriptorMetadata
    metricKind: typing_extensions.Literal[
        "METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"
    ]
    monitoredResourceTypes: _list[str]
    name: str
    type: str
    unit: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "BOOL",
        "INT64",
        "DOUBLE",
        "STRING",
        "DISTRIBUTION",
        "MONEY",
    ]

@typing.type_check_only
class MetricDescriptorMetadata(typing_extensions.TypedDict, total=False):
    ingestDelay: str
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    samplePeriod: str

@typing.type_check_only
class MonitoredResource(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    type: str

@typing.type_check_only
class MonitoredResourceDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    name: str
    type: str

@typing.type_check_only
class MonitoredResourceMetadata(typing_extensions.TypedDict, total=False):
    systemLabels: dict[str, typing.Any]
    userLabels: dict[str, typing.Any]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class RequestLog(typing_extensions.TypedDict, total=False):
    appEngineRelease: str
    appId: str
    cost: float
    endTime: str
    finished: bool
    first: bool
    host: str
    httpVersion: str
    instanceId: str
    instanceIndex: int
    ip: str
    latency: str
    line: _list[LogLine]
    megaCycles: str
    method: str
    moduleId: str
    nickname: str
    pendingTime: str
    referrer: str
    requestId: str
    resource: str
    responseSize: str
    sourceReference: _list[SourceReference]
    spanId: str
    startTime: str
    status: int
    taskName: str
    taskQueueName: str
    traceId: str
    traceSampled: bool
    urlMapEntry: str
    userAgent: str
    versionId: str
    wasLoadingRequest: bool

@typing.type_check_only
class Settings(typing_extensions.TypedDict, total=False):
    disableDefaultSink: bool
    kmsKeyName: str
    kmsServiceAccountId: str
    name: str
    storageLocation: str

@typing.type_check_only
class SourceLocation(typing_extensions.TypedDict, total=False):
    file: str
    functionName: str
    line: str

@typing.type_check_only
class SourceReference(typing_extensions.TypedDict, total=False):
    repository: str
    revisionId: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SuppressionInfo(typing_extensions.TypedDict, total=False):
    reason: typing_extensions.Literal[
        "REASON_UNSPECIFIED", "RATE_LIMIT", "NOT_CONSUMED"
    ]
    suppressedCount: int

@typing.type_check_only
class TailLogEntriesRequest(typing_extensions.TypedDict, total=False):
    bufferWindow: str
    filter: str
    resourceNames: _list[str]

@typing.type_check_only
class TailLogEntriesResponse(typing_extensions.TypedDict, total=False):
    entries: _list[LogEntry]
    suppressionInfo: _list[SuppressionInfo]

@typing.type_check_only
class UndeleteBucketRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class WriteLogEntriesRequest(typing_extensions.TypedDict, total=False):
    dryRun: bool
    entries: _list[LogEntry]
    labels: dict[str, typing.Any]
    logName: str
    partialSuccess: bool
    resource: MonitoredResource

@typing.type_check_only
class WriteLogEntriesResponse(typing_extensions.TypedDict, total=False): ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CancelExecutionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Error(typing_extensions.TypedDict, total=False):
    context: str
    payload: str
    stackTrace: StackTrace

@typing.type_check_only
class Execution(typing_extensions.TypedDict, total=False):
    argument: str
    callLogLevel: typing_extensions.Literal[
        "CALL_LOG_LEVEL_UNSPECIFIED", "LOG_ALL_CALLS", "LOG_ERRORS_ONLY"
    ]
    endTime: str
    error: Error
    name: str
    result: str
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "SUCCEEDED", "FAILED", "CANCELLED"
    ]
    status: Status
    workflowRevisionId: str

@typing.type_check_only
class ListExecutionsResponse(typing_extensions.TypedDict, total=False):
    executions: _list[Execution]
    nextPageToken: str

@typing.type_check_only
class Position(typing_extensions.TypedDict, total=False):
    column: str
    length: str
    line: str

@typing.type_check_only
class StackTrace(typing_extensions.TypedDict, total=False):
    elements: _list[StackTraceElement]

@typing.type_check_only
class StackTraceElement(typing_extensions.TypedDict, total=False):
    position: Position
    routine: str
    step: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    currentSteps: _list[Step]

@typing.type_check_only
class Step(typing_extensions.TypedDict, total=False):
    routine: str
    step: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AptArtifact(typing_extensions.TypedDict, total=False):
    architecture: str
    component: str
    controlFile: str
    name: str
    packageName: str
    packageType: typing_extensions.Literal[
        "PACKAGE_TYPE_UNSPECIFIED", "BINARY", "SOURCE"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GoogleDevtoolsArtifactregistryV1beta2File(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    hashes: _list[Hash]
    name: str
    owner: str
    sizeBytes: str
    updateTime: str

@typing.type_check_only
class Hash(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["HASH_TYPE_UNSPECIFIED", "SHA256", "MD5"]
    value: str

@typing.type_check_only
class ImportAptArtifactsErrorInfo(typing_extensions.TypedDict, total=False):
    error: Status
    gcsSource: ImportAptArtifactsGcsSource

@typing.type_check_only
class ImportAptArtifactsGcsSource(typing_extensions.TypedDict, total=False):
    uris: _list[str]
    useWildcards: bool

@typing.type_check_only
class ImportAptArtifactsMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ImportAptArtifactsRequest(typing_extensions.TypedDict, total=False):
    gcsSource: ImportAptArtifactsGcsSource

@typing.type_check_only
class ImportAptArtifactsResponse(typing_extensions.TypedDict, total=False):
    aptArtifacts: _list[AptArtifact]
    errors: _list[ImportAptArtifactsErrorInfo]

@typing.type_check_only
class ImportYumArtifactsErrorInfo(typing_extensions.TypedDict, total=False):
    error: Status
    gcsSource: ImportYumArtifactsGcsSource

@typing.type_check_only
class ImportYumArtifactsGcsSource(typing_extensions.TypedDict, total=False):
    uris: _list[str]
    useWildcards: bool

@typing.type_check_only
class ImportYumArtifactsMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ImportYumArtifactsRequest(typing_extensions.TypedDict, total=False):
    gcsSource: ImportYumArtifactsGcsSource

@typing.type_check_only
class ImportYumArtifactsResponse(typing_extensions.TypedDict, total=False):
    errors: _list[ImportYumArtifactsErrorInfo]
    yumArtifacts: _list[YumArtifact]

@typing.type_check_only
class ListFilesResponse(typing_extensions.TypedDict, total=False):
    files: _list[GoogleDevtoolsArtifactregistryV1beta2File]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListPackagesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    packages: _list[Package]

@typing.type_check_only
class ListRepositoriesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    repositories: _list[Repository]

@typing.type_check_only
class ListTagsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    tags: _list[Tag]

@typing.type_check_only
class ListVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    versions: _list[Version]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class MavenRepositoryConfig(typing_extensions.TypedDict, total=False):
    allowSnapshotOverwrites: bool
    versionPolicy: typing_extensions.Literal[
        "VERSION_POLICY_UNSPECIFIED", "RELEASE", "SNAPSHOT"
    ]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Package(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    name: str
    updateTime: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class ProjectSettings(typing_extensions.TypedDict, total=False):
    legacyRedirectionState: typing_extensions.Literal[
        "REDIRECTION_STATE_UNSPECIFIED",
        "REDIRECTION_FROM_GCR_IO_DISABLED",
        "REDIRECTION_FROM_GCR_IO_ENABLED",
        "REDIRECTION_FROM_GCR_IO_FINALIZED",
    ]
    name: str

@typing.type_check_only
class Repository(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    format: typing_extensions.Literal[
        "FORMAT_UNSPECIFIED", "DOCKER", "MAVEN", "NPM", "APT", "YUM", "PYTHON"
    ]
    kmsKeyName: str
    labels: dict[str, typing.Any]
    mavenConfig: MavenRepositoryConfig
    name: str
    sizeBytes: str
    updateTime: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class Tag(typing_extensions.TypedDict, total=False):
    name: str
    version: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UploadAptArtifactMediaResponse(typing_extensions.TypedDict, total=False):
    operation: Operation

@typing.type_check_only
class UploadAptArtifactMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UploadAptArtifactRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UploadAptArtifactResponse(typing_extensions.TypedDict, total=False):
    aptArtifacts: _list[AptArtifact]

@typing.type_check_only
class UploadYumArtifactMediaResponse(typing_extensions.TypedDict, total=False):
    operation: Operation

@typing.type_check_only
class UploadYumArtifactMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UploadYumArtifactRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UploadYumArtifactResponse(typing_extensions.TypedDict, total=False):
    yumArtifacts: _list[YumArtifact]

@typing.type_check_only
class Version(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    metadata: dict[str, typing.Any]
    name: str
    relatedTags: _list[Tag]
    updateTime: str

@typing.type_check_only
class YumArtifact(typing_extensions.TypedDict, total=False):
    architecture: str
    name: str
    packageName: str
    packageType: typing_extensions.Literal[
        "PACKAGE_TYPE_UNSPECIFIED", "BINARY", "SOURCE"
    ]



from _typeshed import Incomplete

class Schemas:
    schemas: Incomplete
    pretty: Incomplete
    def __init__(self, discovery) -> None: ...
    def prettyPrintByName(self, name): ...
    def prettyPrintSchema(self, schema): ...
    def get(self, name, default: Incomplete | None = ...): ...

class _SchemaToStruct:
    value: Incomplete
    string: Incomplete
    schema: Incomplete
    dent: Incomplete
    from_cache: Incomplete
    seen: Incomplete
    def __init__(self, schema, seen, dent: int = ...) -> None: ...
    def emit(self, text) -> None: ...
    def emitBegin(self, text) -> None: ...
    def emitEnd(self, text, comment) -> None: ...
    def indent(self) -> None: ...
    def undent(self) -> None: ...
    def to_str(self, from_cache): ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Activities(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Activity]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Activity(typing_extensions.TypedDict, total=False):
    actor: dict[str, typing.Any]
    etag: str
    events: _list[dict[str, typing.Any]]
    id: dict[str, typing.Any]
    ipAddress: str
    kind: str
    ownerDomain: str

@typing.type_check_only
class Channel(typing_extensions.TypedDict, total=False):
    address: str
    expiration: str
    id: str
    kind: str
    params: dict[str, typing.Any]
    payload: bool
    resourceId: str
    resourceUri: str
    token: str
    type: str

@typing.type_check_only
class NestedParameter(typing_extensions.TypedDict, total=False):
    boolValue: bool
    intValue: str
    multiBoolValue: _list[bool]
    multiIntValue: _list[str]
    multiValue: _list[str]
    name: str
    value: str

@typing.type_check_only
class UsageReport(typing_extensions.TypedDict, total=False):
    date: str
    entity: dict[str, typing.Any]
    etag: str
    kind: str
    parameters: _list[dict[str, typing.Any]]

@typing.type_check_only
class UsageReports(typing_extensions.TypedDict, total=False):
    etag: str
    kind: str
    nextPageToken: str
    usageReports: _list[UsageReport]
    warnings: _list[dict[str, typing.Any]]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AutoscalingLimits(typing_extensions.TypedDict, total=False):
    maxServeNodes: int
    minServeNodes: int

@typing.type_check_only
class AutoscalingTargets(typing_extensions.TypedDict, total=False):
    cpuUtilizationPercent: int

@typing.type_check_only
class Backup(typing_extensions.TypedDict, total=False):
    encryptionInfo: EncryptionInfo
    endTime: str
    expireTime: str
    name: str
    sizeBytes: str
    sourceTable: str
    startTime: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "CREATING", "READY"]

@typing.type_check_only
class BackupInfo(typing_extensions.TypedDict, total=False):
    backup: str
    endTime: str
    sourceTable: str
    startTime: str

@typing.type_check_only
class Cluster(typing_extensions.TypedDict, total=False):
    clusterConfig: ClusterConfig
    defaultStorageType: typing_extensions.Literal[
        "STORAGE_TYPE_UNSPECIFIED", "SSD", "HDD"
    ]
    encryptionConfig: EncryptionConfig
    location: str
    name: str
    serveNodes: int
    state: typing_extensions.Literal[
        "STATE_NOT_KNOWN", "READY", "CREATING", "RESIZING", "DISABLED"
    ]

@typing.type_check_only
class ClusterAutoscalingConfig(typing_extensions.TypedDict, total=False):
    autoscalingLimits: AutoscalingLimits
    autoscalingTargets: AutoscalingTargets

@typing.type_check_only
class ClusterConfig(typing_extensions.TypedDict, total=False):
    clusterAutoscalingConfig: ClusterAutoscalingConfig

@typing.type_check_only
class CreateBackupMetadata(typing_extensions.TypedDict, total=False):
    endTime: str
    name: str
    sourceTable: str
    startTime: str

@typing.type_check_only
class CreateClusterMetadata(typing_extensions.TypedDict, total=False):
    finishTime: str
    originalRequest: CreateClusterRequest
    requestTime: str
    tables: dict[str, typing.Any]

@typing.type_check_only
class CreateClusterRequest(typing_extensions.TypedDict, total=False):
    cluster: Cluster
    clusterId: str
    parent: str

@typing.type_check_only
class CreateInstanceMetadata(typing_extensions.TypedDict, total=False):
    finishTime: str
    originalRequest: CreateInstanceRequest
    requestTime: str

@typing.type_check_only
class CreateInstanceRequest(typing_extensions.TypedDict, total=False):
    clusters: dict[str, typing.Any]
    instance: Instance
    instanceId: str
    parent: str

@typing.type_check_only
class EncryptionConfig(typing_extensions.TypedDict, total=False):
    kmsKeyName: str

@typing.type_check_only
class EncryptionInfo(typing_extensions.TypedDict, total=False):
    encryptionStatus: Status
    encryptionType: typing_extensions.Literal[
        "ENCRYPTION_TYPE_UNSPECIFIED",
        "GOOGLE_DEFAULT_ENCRYPTION",
        "CUSTOMER_MANAGED_ENCRYPTION",
    ]
    kmsKeyVersion: str

@typing.type_check_only
class Instance(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    state: typing_extensions.Literal["STATE_NOT_KNOWN", "READY", "CREATING"]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "PRODUCTION", "DEVELOPMENT"]

@typing.type_check_only
class OperationProgress(typing_extensions.TypedDict, total=False):
    endTime: str
    progressPercent: int
    startTime: str

@typing.type_check_only
class OptimizeRestoredTableMetadata(typing_extensions.TypedDict, total=False):
    name: str
    progress: OperationProgress

@typing.type_check_only
class PartialUpdateClusterMetadata(typing_extensions.TypedDict, total=False):
    finishTime: str
    originalRequest: PartialUpdateClusterRequest
    requestTime: str

@typing.type_check_only
class PartialUpdateClusterRequest(typing_extensions.TypedDict, total=False):
    cluster: Cluster
    updateMask: str

@typing.type_check_only
class PartialUpdateInstanceRequest(typing_extensions.TypedDict, total=False):
    instance: Instance
    updateMask: str

@typing.type_check_only
class RestoreTableMetadata(typing_extensions.TypedDict, total=False):
    backupInfo: BackupInfo
    name: str
    optimizeTableOperationName: str
    progress: OperationProgress
    sourceType: typing_extensions.Literal["RESTORE_SOURCE_TYPE_UNSPECIFIED", "BACKUP"]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TableProgress(typing_extensions.TypedDict, total=False):
    estimatedCopiedBytes: str
    estimatedSizeBytes: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PENDING", "COPYING", "COMPLETED", "CANCELLED"
    ]

@typing.type_check_only
class UpdateAppProfileMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UpdateClusterMetadata(typing_extensions.TypedDict, total=False):
    finishTime: str
    originalRequest: Cluster
    requestTime: str

@typing.type_check_only
class UpdateInstanceMetadata(typing_extensions.TypedDict, total=False):
    finishTime: str
    originalRequest: PartialUpdateInstanceRequest
    requestTime: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    bidderLocation: _list[dict[str, typing.Any]]
    cookieMatchingNid: str
    cookieMatchingUrl: str
    id: int
    kind: str
    maximumActiveCreatives: int
    maximumTotalQps: int
    numberActiveCreatives: int

@typing.type_check_only
class AccountsList(typing_extensions.TypedDict, total=False):
    items: _list[Account]
    kind: str

@typing.type_check_only
class Creative(typing_extensions.TypedDict, total=False):
    HTMLSnippet: str
    accountId: int
    advertiserId: _list[str]
    advertiserName: str
    agencyId: str
    apiUploadTimestamp: str
    attribute: _list[int]
    buyerCreativeId: str
    clickThroughUrl: _list[str]
    corrections: _list[dict[str, typing.Any]]
    disapprovalReasons: _list[dict[str, typing.Any]]
    filteringReasons: dict[str, typing.Any]
    height: int
    impressionTrackingUrl: _list[str]
    kind: str
    productCategories: _list[int]
    restrictedCategories: _list[int]
    sensitiveCategories: _list[int]
    status: str
    vendorType: _list[int]
    version: int
    videoURL: str
    width: int

@typing.type_check_only
class CreativesList(typing_extensions.TypedDict, total=False):
    items: _list[Creative]
    kind: str
    nextPageToken: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class NetworkManagementResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GlobalResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ConnectivityTestsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: ConnectivityTest = ...,
                        testId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> ConnectivityTestHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        options_requestedPolicyVersion: int = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListConnectivityTestsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListConnectivityTestsResponseHttpRequest,
                        previous_response: ListConnectivityTestsResponse,
                    ) -> ListConnectivityTestsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: ConnectivityTest = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def rerun(
                        self,
                        *,
                        name: str,
                        body: RerunConnectivityTestRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...

                @typing.type_check_only
                class OperationsResource(googleapiclient.discovery.Resource):
                    def cancel(
                        self,
                        *,
                        name: str,
                        body: CancelOperationRequest = ...,
                        **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def list(
                        self,
                        *,
                        name: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListOperationsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListOperationsResponseHttpRequest,
                        previous_response: ListOperationsResponse,
                    ) -> ListOperationsResponseHttpRequest | None: ...

                def connectivityTests(self) -> ConnectivityTestsResource: ...
                def operations(self) -> OperationsResource: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def global_(self) -> GlobalResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class ConnectivityTestHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConnectivityTest: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListConnectivityTestsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectivityTestsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudTraceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class TracesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SpansResource(googleapiclient.discovery.Resource):
                def createSpan(
                    self, *, name: str, body: Span = ..., **kwargs: typing.Any
                ) -> SpanHttpRequest: ...

            def batchWrite(
                self,
                *,
                name: str,
                body: BatchWriteSpansRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def spans(self) -> SpansResource: ...

        def traces(self) -> TracesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class SpanHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Span: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AchievementDefinition(typing_extensions.TypedDict, total=False):
    achievementType: typing_extensions.Literal[
        "ACHIEVEMENT_TYPE_UNSPECIFIED", "STANDARD", "INCREMENTAL"
    ]
    description: str
    experiencePoints: str
    formattedTotalSteps: str
    id: str
    initialState: typing_extensions.Literal[
        "INITIAL_ACHIEVEMENT_STATE_UNSPECIFIED", "HIDDEN", "REVEALED", "UNLOCKED"
    ]
    isRevealedIconUrlDefault: bool
    isUnlockedIconUrlDefault: bool
    kind: str
    name: str
    revealedIconUrl: str
    totalSteps: int
    unlockedIconUrl: str

@typing.type_check_only
class AchievementDefinitionsListResponse(typing_extensions.TypedDict, total=False):
    items: _list[AchievementDefinition]
    kind: str
    nextPageToken: str

@typing.type_check_only
class AchievementIncrementResponse(typing_extensions.TypedDict, total=False):
    currentSteps: int
    kind: str
    newlyUnlocked: bool

@typing.type_check_only
class AchievementRevealResponse(typing_extensions.TypedDict, total=False):
    currentState: typing_extensions.Literal[
        "REVEAL_ACHIEVEMENT_STATE_UNSPECIFIED", "REVEALED", "UNLOCKED"
    ]
    kind: str

@typing.type_check_only
class AchievementSetStepsAtLeastResponse(typing_extensions.TypedDict, total=False):
    currentSteps: int
    kind: str
    newlyUnlocked: bool

@typing.type_check_only
class AchievementUnlockResponse(typing_extensions.TypedDict, total=False):
    kind: str
    newlyUnlocked: bool

@typing.type_check_only
class AchievementUpdateMultipleRequest(typing_extensions.TypedDict, total=False):
    kind: str
    updates: _list[AchievementUpdateRequest]

@typing.type_check_only
class AchievementUpdateMultipleResponse(typing_extensions.TypedDict, total=False):
    kind: str
    updatedAchievements: _list[AchievementUpdateResponse]

@typing.type_check_only
class AchievementUpdateRequest(typing_extensions.TypedDict, total=False):
    achievementId: str
    incrementPayload: GamesAchievementIncrement
    kind: str
    setStepsAtLeastPayload: GamesAchievementSetStepsAtLeast
    updateType: typing_extensions.Literal[
        "ACHIEVEMENT_UPDATE_TYPE_UNSPECIFIED",
        "REVEAL",
        "UNLOCK",
        "INCREMENT",
        "SET_STEPS_AT_LEAST",
    ]

@typing.type_check_only
class AchievementUpdateResponse(typing_extensions.TypedDict, total=False):
    achievementId: str
    currentState: typing_extensions.Literal[
        "UPDATED_ACHIEVEMENT_STATE_UNSPECIFIED", "HIDDEN", "REVEALED", "UNLOCKED"
    ]
    currentSteps: int
    kind: str
    newlyUnlocked: bool
    updateOccurred: bool

@typing.type_check_only
class Application(typing_extensions.TypedDict, total=False):
    achievement_count: int
    assets: _list[ImageAsset]
    author: str
    category: ApplicationCategory
    description: str
    enabledFeatures: _list[str]
    id: str
    instances: _list[Instance]
    kind: str
    lastUpdatedTimestamp: str
    leaderboard_count: int
    name: str
    themeColor: str

@typing.type_check_only
class ApplicationCategory(typing_extensions.TypedDict, total=False):
    kind: str
    primary: str
    secondary: str

@typing.type_check_only
class ApplicationVerifyResponse(typing_extensions.TypedDict, total=False):
    alternate_player_id: str
    kind: str
    player_id: str

@typing.type_check_only
class Category(typing_extensions.TypedDict, total=False):
    category: str
    experiencePoints: str
    kind: str

@typing.type_check_only
class CategoryListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Category]
    kind: str
    nextPageToken: str

@typing.type_check_only
class EndPoint(typing_extensions.TypedDict, total=False):
    url: str

@typing.type_check_only
class EventBatchRecordFailure(typing_extensions.TypedDict, total=False):
    failureCause: typing_extensions.Literal[
        "EVENT_FAILURE_CAUSE_UNSPECIFIED",
        "TOO_LARGE",
        "TIME_PERIOD_EXPIRED",
        "TIME_PERIOD_SHORT",
        "TIME_PERIOD_LONG",
        "ALREADY_UPDATED",
        "RECORD_RATE_HIGH",
    ]
    kind: str
    range: EventPeriodRange

@typing.type_check_only
class EventChild(typing_extensions.TypedDict, total=False):
    childId: str
    kind: str

@typing.type_check_only
class EventDefinition(typing_extensions.TypedDict, total=False):
    childEvents: _list[EventChild]
    description: str
    displayName: str
    id: str
    imageUrl: str
    isDefaultImageUrl: bool
    kind: str
    visibility: typing_extensions.Literal[
        "EVENT_VISIBILITY_UNSPECIFIED", "REVEALED", "HIDDEN"
    ]

@typing.type_check_only
class EventDefinitionListResponse(typing_extensions.TypedDict, total=False):
    items: _list[EventDefinition]
    kind: str
    nextPageToken: str

@typing.type_check_only
class EventPeriodRange(typing_extensions.TypedDict, total=False):
    kind: str
    periodEndMillis: str
    periodStartMillis: str

@typing.type_check_only
class EventPeriodUpdate(typing_extensions.TypedDict, total=False):
    kind: str
    timePeriod: EventPeriodRange
    updates: _list[EventUpdateRequest]

@typing.type_check_only
class EventRecordFailure(typing_extensions.TypedDict, total=False):
    eventId: str
    failureCause: typing_extensions.Literal[
        "EVENT_UPDATE_FAILURE_CAUSE_UNSPECIFIED", "NOT_FOUND", "INVALID_UPDATE_VALUE"
    ]
    kind: str

@typing.type_check_only
class EventRecordRequest(typing_extensions.TypedDict, total=False):
    currentTimeMillis: str
    kind: str
    requestId: str
    timePeriods: _list[EventPeriodUpdate]

@typing.type_check_only
class EventUpdateRequest(typing_extensions.TypedDict, total=False):
    definitionId: str
    kind: str
    updateCount: str

@typing.type_check_only
class EventUpdateResponse(typing_extensions.TypedDict, total=False):
    batchFailures: _list[EventBatchRecordFailure]
    eventFailures: _list[EventRecordFailure]
    kind: str
    playerEvents: _list[PlayerEvent]

@typing.type_check_only
class GamesAchievementIncrement(typing_extensions.TypedDict, total=False):
    kind: str
    requestId: str
    steps: int

@typing.type_check_only
class GamesAchievementSetStepsAtLeast(typing_extensions.TypedDict, total=False):
    kind: str
    steps: int

@typing.type_check_only
class ImageAsset(typing_extensions.TypedDict, total=False):
    height: int
    kind: str
    name: str
    url: str
    width: int

@typing.type_check_only
class Instance(typing_extensions.TypedDict, total=False):
    acquisitionUri: str
    androidInstance: InstanceAndroidDetails
    iosInstance: InstanceIosDetails
    kind: str
    name: str
    platformType: typing_extensions.Literal[
        "PLATFORM_TYPE_UNSPECIFIED", "ANDROID", "IOS", "WEB_APP"
    ]
    realtimePlay: bool
    turnBasedPlay: bool
    webInstance: InstanceWebDetails

@typing.type_check_only
class InstanceAndroidDetails(typing_extensions.TypedDict, total=False):
    enablePiracyCheck: bool
    kind: str
    packageName: str
    preferred: bool

@typing.type_check_only
class InstanceIosDetails(typing_extensions.TypedDict, total=False):
    bundleIdentifier: str
    itunesAppId: str
    kind: str
    preferredForIpad: bool
    preferredForIphone: bool
    supportIpad: bool
    supportIphone: bool

@typing.type_check_only
class InstanceWebDetails(typing_extensions.TypedDict, total=False):
    kind: str
    launchUrl: str
    preferred: bool

@typing.type_check_only
class Leaderboard(typing_extensions.TypedDict, total=False):
    iconUrl: str
    id: str
    isIconUrlDefault: bool
    kind: str
    name: str
    order: typing_extensions.Literal[
        "SCORE_ORDER_UNSPECIFIED", "LARGER_IS_BETTER", "SMALLER_IS_BETTER"
    ]

@typing.type_check_only
class LeaderboardEntry(typing_extensions.TypedDict, total=False):
    formattedScore: str
    formattedScoreRank: str
    kind: str
    player: Player
    scoreRank: str
    scoreTag: str
    scoreValue: str
    timeSpan: typing_extensions.Literal[
        "SCORE_TIME_SPAN_UNSPECIFIED", "ALL_TIME", "WEEKLY", "DAILY"
    ]
    writeTimestampMillis: str

@typing.type_check_only
class LeaderboardListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Leaderboard]
    kind: str
    nextPageToken: str

@typing.type_check_only
class LeaderboardScoreRank(typing_extensions.TypedDict, total=False):
    formattedNumScores: str
    formattedRank: str
    kind: str
    numScores: str
    rank: str

@typing.type_check_only
class LeaderboardScores(typing_extensions.TypedDict, total=False):
    items: _list[LeaderboardEntry]
    kind: str
    nextPageToken: str
    numScores: str
    playerScore: LeaderboardEntry
    prevPageToken: str

@typing.type_check_only
class MetagameConfig(typing_extensions.TypedDict, total=False):
    currentVersion: int
    kind: str
    playerLevels: _list[PlayerLevel]

@typing.type_check_only
class Player(typing_extensions.TypedDict, total=False):
    avatarImageUrl: str
    bannerUrlLandscape: str
    bannerUrlPortrait: str
    displayName: str
    experienceInfo: PlayerExperienceInfo
    friendStatus: typing_extensions.Literal[
        "FRIEND_STATUS_UNSPECIFIED", "NO_RELATIONSHIP", "FRIEND"
    ]
    gamePlayerId: str
    kind: str
    name: dict[str, typing.Any]
    originalPlayerId: str
    playerId: str
    profileSettings: ProfileSettings
    title: str

@typing.type_check_only
class PlayerAchievement(typing_extensions.TypedDict, total=False):
    achievementState: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "HIDDEN", "REVEALED", "UNLOCKED"
    ]
    currentSteps: int
    experiencePoints: str
    formattedCurrentStepsString: str
    id: str
    kind: str
    lastUpdatedTimestamp: str

@typing.type_check_only
class PlayerAchievementListResponse(typing_extensions.TypedDict, total=False):
    items: _list[PlayerAchievement]
    kind: str
    nextPageToken: str

@typing.type_check_only
class PlayerEvent(typing_extensions.TypedDict, total=False):
    definitionId: str
    formattedNumEvents: str
    kind: str
    numEvents: str
    playerId: str

@typing.type_check_only
class PlayerEventListResponse(typing_extensions.TypedDict, total=False):
    items: _list[PlayerEvent]
    kind: str
    nextPageToken: str

@typing.type_check_only
class PlayerExperienceInfo(typing_extensions.TypedDict, total=False):
    currentExperiencePoints: str
    currentLevel: PlayerLevel
    kind: str
    lastLevelUpTimestampMillis: str
    nextLevel: PlayerLevel

@typing.type_check_only
class PlayerLeaderboardScore(typing_extensions.TypedDict, total=False):
    friendsRank: LeaderboardScoreRank
    kind: str
    leaderboard_id: str
    publicRank: LeaderboardScoreRank
    scoreString: str
    scoreTag: str
    scoreValue: str
    socialRank: LeaderboardScoreRank
    timeSpan: typing_extensions.Literal[
        "SCORE_TIME_SPAN_UNSPECIFIED", "ALL_TIME", "WEEKLY", "DAILY"
    ]
    writeTimestamp: str

@typing.type_check_only
class PlayerLeaderboardScoreListResponse(typing_extensions.TypedDict, total=False):
    items: _list[PlayerLeaderboardScore]
    kind: str
    nextPageToken: str
    player: Player

@typing.type_check_only
class PlayerLevel(typing_extensions.TypedDict, total=False):
    kind: str
    level: int
    maxExperiencePoints: str
    minExperiencePoints: str

@typing.type_check_only
class PlayerListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Player]
    kind: str
    nextPageToken: str

@typing.type_check_only
class PlayerScore(typing_extensions.TypedDict, total=False):
    formattedScore: str
    kind: str
    score: str
    scoreTag: str
    timeSpan: typing_extensions.Literal[
        "SCORE_TIME_SPAN_UNSPECIFIED", "ALL_TIME", "WEEKLY", "DAILY"
    ]

@typing.type_check_only
class PlayerScoreListResponse(typing_extensions.TypedDict, total=False):
    kind: str
    submittedScores: _list[PlayerScoreResponse]

@typing.type_check_only
class PlayerScoreResponse(typing_extensions.TypedDict, total=False):
    beatenScoreTimeSpans: _list[str]
    formattedScore: str
    kind: str
    leaderboardId: str
    scoreTag: str
    unbeatenScores: _list[PlayerScore]

@typing.type_check_only
class PlayerScoreSubmissionList(typing_extensions.TypedDict, total=False):
    kind: str
    scores: _list[ScoreSubmission]

@typing.type_check_only
class ProfileSettings(typing_extensions.TypedDict, total=False):
    friendsListVisibility: typing_extensions.Literal[
        "FRIENDS_LIST_VISIBILITY_UNSPECIFIED",
        "VISIBLE",
        "REQUEST_REQUIRED",
        "UNAVAILABLE",
    ]
    kind: str
    profileVisible: bool

@typing.type_check_only
class RevisionCheckResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    revisionStatus: typing_extensions.Literal[
        "REVISION_STATUS_UNSPECIFIED", "OK", "DEPRECATED", "INVALID"
    ]

@typing.type_check_only
class ScopedPlayerIds(typing_extensions.TypedDict, total=False):
    developerPlayerKey: str
    gamePlayerId: str

@typing.type_check_only
class ScoreSubmission(typing_extensions.TypedDict, total=False):
    kind: str
    leaderboardId: str
    score: str
    scoreTag: str
    signature: str

@typing.type_check_only
class Snapshot(typing_extensions.TypedDict, total=False):
    coverImage: SnapshotImage
    description: str
    driveId: str
    durationMillis: str
    id: str
    kind: str
    lastModifiedMillis: str
    progressValue: str
    title: str
    type: typing_extensions.Literal["SNAPSHOT_TYPE_UNSPECIFIED", "SAVE_GAME"]
    uniqueName: str

@typing.type_check_only
class SnapshotImage(typing_extensions.TypedDict, total=False):
    height: int
    kind: str
    mime_type: str
    url: str
    width: int

@typing.type_check_only
class SnapshotListResponse(typing_extensions.TypedDict, total=False):
    items: _list[Snapshot]
    kind: str
    nextPageToken: str

@typing.type_check_only
class StatsResponse(typing_extensions.TypedDict, total=False):
    avg_session_length_minutes: float
    churn_probability: float
    days_since_last_played: int
    high_spender_probability: float
    kind: str
    num_purchases: int
    num_sessions: int
    num_sessions_percentile: float
    spend_percentile: float
    spend_probability: float
    total_spend_next_28_days: float



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class NetworkconnectivityResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GlobalResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class HubsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: Hub = ...,
                        hubId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def delete(
                        self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> HubHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        options_requestedPolicyVersion: int = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListHubsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListHubsResponseHttpRequest,
                        previous_response: ListHubsResponse,
                    ) -> ListHubsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: Hub = ...,
                        requestId: str = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...

                def hubs(self) -> HubsResource: ...

            @typing.type_check_only
            class InternalRangesResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: GoogleLongrunningCancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ServiceClassesResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ServiceConnectionMapsResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ServiceConnectionPoliciesResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class SpokesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Spoke = ...,
                    requestId: str = ...,
                    spokeId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> SpokeHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListSpokesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListSpokesResponseHttpRequest,
                    previous_response: ListSpokesResponse,
                ) -> ListSpokesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Spoke = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def global_(self) -> GlobalResource: ...
            def internalRanges(self) -> InternalRangesResource: ...
            def operations(self) -> OperationsResource: ...
            def serviceClasses(self) -> ServiceClassesResource: ...
            def serviceConnectionMaps(self) -> ServiceConnectionMapsResource: ...
            def serviceConnectionPolicies(
                self,
            ) -> ServiceConnectionPoliciesResource: ...
            def spokes(self) -> SpokesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class HubHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Hub: ...

@typing.type_check_only
class ListHubsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHubsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListSpokesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSpokesResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class SpokeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Spoke: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseManagementResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AvailableProjectsResource(googleapiclient.discovery.Resource):
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> ListAvailableProjectsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListAvailableProjectsResponseHttpRequest,
            previous_response: ListAvailableProjectsResponse,
        ) -> ListAvailableProjectsResponseHttpRequest | None: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AndroidAppsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ShaResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: ShaCertificate = ...,
                    **kwargs: typing.Any
                ) -> ShaCertificateHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def list(
                    self, *, parent: str, **kwargs: typing.Any
                ) -> ListShaCertificatesResponseHttpRequest: ...

            def create(
                self, *, parent: str, body: AndroidApp = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> AndroidAppHttpRequest: ...
            def getConfig(
                self, *, name: str, **kwargs: typing.Any
            ) -> AndroidAppConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                **kwargs: typing.Any
            ) -> ListAndroidAppsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAndroidAppsResponseHttpRequest,
                previous_response: ListAndroidAppsResponse,
            ) -> ListAndroidAppsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: AndroidApp = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> AndroidAppHttpRequest: ...
            def remove(
                self,
                *,
                name: str,
                body: RemoveAndroidAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteAndroidAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def sha(self) -> ShaResource: ...

        @typing.type_check_only
        class AvailableLocationsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAvailableLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAvailableLocationsResponseHttpRequest,
                previous_response: ListAvailableLocationsResponse,
            ) -> ListAvailableLocationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class DefaultLocationResource(googleapiclient.discovery.Resource):
            def finalize(
                self,
                *,
                parent: str,
                body: FinalizeDefaultLocationRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class IosAppsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: IosApp = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> IosAppHttpRequest: ...
            def getConfig(
                self, *, name: str, **kwargs: typing.Any
            ) -> IosAppConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                **kwargs: typing.Any
            ) -> ListIosAppsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListIosAppsResponseHttpRequest,
                previous_response: ListIosAppsResponse,
            ) -> ListIosAppsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: IosApp = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> IosAppHttpRequest: ...
            def remove(
                self,
                *,
                name: str,
                body: RemoveIosAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteIosAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class WebAppsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: WebApp = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> WebAppHttpRequest: ...
            def getConfig(
                self, *, name: str, **kwargs: typing.Any
            ) -> WebAppConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                **kwargs: typing.Any
            ) -> ListWebAppsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListWebAppsResponseHttpRequest,
                previous_response: ListWebAppsResponse,
            ) -> ListWebAppsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: WebApp = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> WebAppHttpRequest: ...
            def remove(
                self,
                *,
                name: str,
                body: RemoveWebAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteWebAppRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def addFirebase(
            self, *, project: str, body: AddFirebaseRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def addGoogleAnalytics(
            self,
            *,
            parent: str,
            body: AddGoogleAnalyticsRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> FirebaseProjectHttpRequest: ...
        def getAdminSdkConfig(
            self, *, name: str, **kwargs: typing.Any
        ) -> AdminSdkConfigHttpRequest: ...
        def getAnalyticsDetails(
            self, *, name: str, **kwargs: typing.Any
        ) -> AnalyticsDetailsHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            **kwargs: typing.Any
        ) -> ListFirebaseProjectsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListFirebaseProjectsResponseHttpRequest,
            previous_response: ListFirebaseProjectsResponse,
        ) -> ListFirebaseProjectsResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: FirebaseProject = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> FirebaseProjectHttpRequest: ...
        def removeAnalytics(
            self,
            *,
            parent: str,
            body: RemoveAnalyticsRequest = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def searchApps(
            self,
            *,
            parent: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            showDeleted: bool = ...,
            **kwargs: typing.Any
        ) -> SearchFirebaseAppsResponseHttpRequest: ...
        def searchApps_next(
            self,
            previous_request: SearchFirebaseAppsResponseHttpRequest,
            previous_response: SearchFirebaseAppsResponse,
        ) -> SearchFirebaseAppsResponseHttpRequest | None: ...
        def androidApps(self) -> AndroidAppsResource: ...
        def availableLocations(self) -> AvailableLocationsResource: ...
        def defaultLocation(self) -> DefaultLocationResource: ...
        def iosApps(self) -> IosAppsResource: ...
        def webApps(self) -> WebAppsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def availableProjects(self) -> AvailableProjectsResource: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class AdminSdkConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdminSdkConfig: ...

@typing.type_check_only
class AnalyticsDetailsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AnalyticsDetails: ...

@typing.type_check_only
class AndroidAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AndroidApp: ...

@typing.type_check_only
class AndroidAppConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AndroidAppConfig: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FirebaseProjectHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FirebaseProject: ...

@typing.type_check_only
class IosAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IosApp: ...

@typing.type_check_only
class IosAppConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IosAppConfig: ...

@typing.type_check_only
class ListAndroidAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAndroidAppsResponse: ...

@typing.type_check_only
class ListAvailableLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAvailableLocationsResponse: ...

@typing.type_check_only
class ListAvailableProjectsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAvailableProjectsResponse: ...

@typing.type_check_only
class ListFirebaseProjectsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFirebaseProjectsResponse: ...

@typing.type_check_only
class ListIosAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListIosAppsResponse: ...

@typing.type_check_only
class ListShaCertificatesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListShaCertificatesResponse: ...

@typing.type_check_only
class ListWebAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWebAppsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class SearchFirebaseAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchFirebaseAppsResponse: ...

@typing.type_check_only
class ShaCertificateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShaCertificate: ...

@typing.type_check_only
class WebAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebApp: ...

@typing.type_check_only
class WebAppConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebAppConfig: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuthorizeEnvironmentRequest(typing_extensions.TypedDict, total=False):
    accessToken: str
    expireTime: str
    idToken: str

@typing.type_check_only
class CreatePublicKeyRequest(typing_extensions.TypedDict, total=False):
    key: PublicKey

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Environment(typing_extensions.TypedDict, total=False):
    dockerImage: str
    id: str
    name: str
    publicKeys: _list[PublicKey]
    size: typing_extensions.Literal["VM_SIZE_UNSPECIFIED", "DEFAULT", "BOOSTED"]
    sshHost: str
    sshPort: int
    sshUsername: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "DISABLED", "STARTING", "RUNNING", "DELETING"
    ]
    vmSizeExpireTime: str
    webHost: str
    webPorts: _list[int]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class PublicKey(typing_extensions.TypedDict, total=False):
    format: typing_extensions.Literal[
        "FORMAT_UNSPECIFIED",
        "SSH_DSS",
        "SSH_RSA",
        "ECDSA_SHA2_NISTP256",
        "ECDSA_SHA2_NISTP384",
        "ECDSA_SHA2_NISTP521",
    ]
    key: str
    name: str

@typing.type_check_only
class StartEnvironmentMetadata(typing_extensions.TypedDict, total=False):
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "STARTING",
        "UNARCHIVING_DISK",
        "AWAITING_VM",
        "AWAITING_COMPUTE_RESOURCES",
        "FINISHED",
    ]

@typing.type_check_only
class StartEnvironmentRequest(typing_extensions.TypedDict, total=False):
    accessToken: str
    publicKeys: _list[PublicKey]

@typing.type_check_only
class StartEnvironmentResponse(typing_extensions.TypedDict, total=False):
    environment: Environment

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class MonitoringResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class GlobalResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class MetricsScopesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ProjectsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: MonitoredProject = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> MetricsScopeHttpRequest: ...
                def listMetricsScopesByMonitoredProject(
                    self, *, monitoredResourceContainer: str = ..., **kwargs: typing.Any
                ) -> ListMetricsScopesByMonitoredProjectResponseHttpRequest: ...
                def projects(self) -> ProjectsResource: ...

            def metricsScopes(self) -> MetricsScopesResource: ...

        def global_(self) -> GlobalResource: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DashboardsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: Dashboard = ...,
                validateOnly: bool = ...,
                **kwargs: typing.Any
            ) -> DashboardHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> DashboardHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDashboardsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDashboardsResponseHttpRequest,
                previous_response: ListDashboardsResponse,
            ) -> ListDashboardsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Dashboard = ...,
                validateOnly: bool = ...,
                **kwargs: typing.Any
            ) -> DashboardHttpRequest: ...

        @typing.type_check_only
        class LocationResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class PrometheusResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ApiResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class V1Resource(googleapiclient.discovery.Resource):
                        @typing.type_check_only
                        class LabelResource(googleapiclient.discovery.Resource):
                            def values(
                                self,
                                *,
                                name: str,
                                location: str,
                                label: str,
                                end: str = ...,
                                match: str = ...,
                                start: str = ...,
                                **kwargs: typing.Any
                            ) -> HttpBodyHttpRequest: ...

                        @typing.type_check_only
                        class LabelsResource(googleapiclient.discovery.Resource):
                            def list(
                                self,
                                *,
                                name: str,
                                location: str,
                                end: str = ...,
                                match: str = ...,
                                start: str = ...,
                                **kwargs: typing.Any
                            ) -> HttpBodyHttpRequest: ...

                        @typing.type_check_only
                        class MetadataResource(googleapiclient.discovery.Resource):
                            def list(
                                self,
                                *,
                                name: str,
                                location: str,
                                limit: str = ...,
                                metric: str = ...,
                                **kwargs: typing.Any
                            ) -> HttpBodyHttpRequest: ...

                        def query(
                            self,
                            *,
                            name: str,
                            location: str,
                            body: QueryInstantRequest = ...,
                            **kwargs: typing.Any
                        ) -> HttpBodyHttpRequest: ...
                        def query_range(
                            self,
                            *,
                            name: str,
                            location: str,
                            body: QueryRangeRequest = ...,
                            **kwargs: typing.Any
                        ) -> HttpBodyHttpRequest: ...
                        def series(
                            self,
                            *,
                            name: str,
                            location: str,
                            body: QuerySeriesRequest = ...,
                            **kwargs: typing.Any
                        ) -> HttpBodyHttpRequest: ...
                        def label(self) -> LabelResource: ...
                        def labels(self) -> LabelsResource: ...
                        def metadata(self) -> MetadataResource: ...

                    def v1(self) -> V1Resource: ...

                def api(self) -> ApiResource: ...

            def prometheus(self) -> PrometheusResource: ...

        def dashboards(self) -> DashboardsResource: ...
        def location(self) -> LocationResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def locations(self) -> LocationsResource: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DashboardHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Dashboard: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class HttpBodyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> HttpBody: ...

@typing.type_check_only
class ListDashboardsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDashboardsResponse: ...

@typing.type_check_only
class ListMetricsScopesByMonitoredProjectResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMetricsScopesByMonitoredProjectResponse: ...

@typing.type_check_only
class MetricsScopeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MetricsScope: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ApplianceCluster(typing_extensions.TypedDict, total=False):
    resourceLink: str

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Authority(typing_extensions.TypedDict, total=False):
    identityProvider: str
    issuer: str
    oidcJwks: str
    workloadIdentityPool: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ConnectAgentResource(typing_extensions.TypedDict, total=False):
    manifest: str
    type: TypeMeta

@typing.type_check_only
class EdgeCluster(typing_extensions.TypedDict, total=False):
    resourceLink: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GenerateConnectManifestResponse(typing_extensions.TypedDict, total=False):
    manifest: _list[ConnectAgentResource]

@typing.type_check_only
class GkeCluster(typing_extensions.TypedDict, total=False):
    clusterMissing: bool
    resourceLink: str

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class InitializeHubRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class InitializeHubResponse(typing_extensions.TypedDict, total=False):
    serviceIdentity: str
    workloadIdentityPool: str

@typing.type_check_only
class KubernetesMetadata(typing_extensions.TypedDict, total=False):
    kubernetesApiServerVersion: str
    memoryMb: int
    nodeCount: int
    nodeProviderId: str
    updateTime: str
    vcpuCount: int

@typing.type_check_only
class KubernetesResource(typing_extensions.TypedDict, total=False):
    connectResources: _list[ResourceManifest]
    membershipCrManifest: str
    membershipResources: _list[ResourceManifest]
    resourceOptions: ResourceOptions

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListMembershipsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    resources: _list[Membership]
    unreachable: _list[str]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Membership(typing_extensions.TypedDict, total=False):
    authority: Authority
    createTime: str
    deleteTime: str
    description: str
    endpoint: MembershipEndpoint
    externalId: str
    infrastructureType: typing_extensions.Literal[
        "INFRASTRUCTURE_TYPE_UNSPECIFIED", "ON_PREM", "MULTI_CLOUD"
    ]
    labels: dict[str, typing.Any]
    lastConnectionTime: str
    name: str
    state: MembershipState
    uniqueId: str
    updateTime: str

@typing.type_check_only
class MembershipEndpoint(typing_extensions.TypedDict, total=False):
    applianceCluster: ApplianceCluster
    edgeCluster: EdgeCluster
    gkeCluster: GkeCluster
    kubernetesMetadata: KubernetesMetadata
    kubernetesResource: KubernetesResource
    multiCloudCluster: MultiCloudCluster
    onPremCluster: OnPremCluster

@typing.type_check_only
class MembershipState(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED",
        "CREATING",
        "READY",
        "DELETING",
        "UPDATING",
        "SERVICE_UPDATING",
    ]

@typing.type_check_only
class MultiCloudCluster(typing_extensions.TypedDict, total=False):
    clusterMissing: bool
    resourceLink: str

@typing.type_check_only
class OnPremCluster(typing_extensions.TypedDict, total=False):
    adminCluster: bool
    clusterMissing: bool
    clusterType: typing_extensions.Literal[
        "CLUSTERTYPE_UNSPECIFIED", "BOOTSTRAP", "HYBRID", "STANDALONE", "USER"
    ]
    resourceLink: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class ResourceManifest(typing_extensions.TypedDict, total=False):
    clusterScoped: bool
    manifest: str

@typing.type_check_only
class ResourceOptions(typing_extensions.TypedDict, total=False):
    connectVersion: str
    k8sVersion: str
    v1beta1Crd: bool

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TypeMeta(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str



__credits__: str

def parse_mime_type(mime_type): ...
def parse_media_range(range): ...
def fitness_and_quality_parsed(mime_type, parsed_ranges): ...
def quality_parsed(mime_type, parsed_ranges): ...
def quality(mime_type, ranges): ...
def best_match(supported, header): ...



from _typeshed import Incomplete

class Error(Exception): ...

class HttpError(Error):
    resp: Incomplete
    content: Incomplete
    uri: Incomplete
    error_details: str
    reason: Incomplete
    def __init__(self, resp, content, uri: Incomplete | None = ...) -> None: ...
    @property
    def status_code(self): ...

class InvalidJsonError(Error): ...
class UnknownFileType(Error): ...
class UnknownLinkType(Error): ...
class UnknownApiNameOrVersion(Error): ...
class UnacceptableMimeTypeError(Error): ...
class MediaUploadSizeError(Error): ...
class ResumableUploadError(HttpError): ...
class InvalidChunkSizeError(Error): ...
class InvalidNotificationError(Error): ...

class BatchError(HttpError):
    resp: Incomplete
    content: Incomplete
    reason: Incomplete
    def __init__(
        self, reason, resp: Incomplete | None = ..., content: Incomplete | None = ...
    ) -> None: ...

class UnexpectedMethodError(Error):
    def __init__(self, methodId: Incomplete | None = ...) -> None: ...

class UnexpectedBodyError(Error):
    def __init__(self, expected, provided) -> None: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class LocalservicesResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountReportsResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            endDate_day: int = ...,
            endDate_month: int = ...,
            endDate_year: int = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            query: str = ...,
            startDate_day: int = ...,
            startDate_month: int = ...,
            startDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponseHttpRequest,
            previous_response: GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse,
        ) -> GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponseHttpRequest | None: ...

    @typing.type_check_only
    class DetailedLeadReportsResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            endDate_day: int = ...,
            endDate_month: int = ...,
            endDate_year: int = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            query: str = ...,
            startDate_day: int = ...,
            startDate_month: int = ...,
            startDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponseHttpRequest,
            previous_response: GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse,
        ) -> GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accountReports(self) -> AccountReportsResource: ...
    def detailedLeadReports(self) -> DetailedLeadReportsResource: ...

@typing.type_check_only
class GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse: ...

@typing.type_check_only
class GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudBuildResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class WorkerPoolsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: WorkerPool = ...,
                    workerPoolId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, etag: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> WorkerPoolHttpRequest: ...
                def list(
                    self, *, parent: str, **kwargs: typing.Any
                ) -> ListWorkerPoolsResponseHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: WorkerPool = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def operations(self) -> OperationsResource: ...
            def workerPools(self) -> WorkerPoolsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListWorkerPoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWorkerPoolsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class WorkerPoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WorkerPool: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    id: str
    kind: str
    name: str
    status: str

@typing.type_check_only
class Accounts(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Account]
    kind: str

@typing.type_check_only
class AdClient(typing_extensions.TypedDict, total=False):
    arcOptIn: bool
    id: str
    kind: str
    productCode: str
    supportsReporting: bool

@typing.type_check_only
class AdClients(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[AdClient]
    kind: str
    nextPageToken: str

@typing.type_check_only
class AdCode(typing_extensions.TypedDict, total=False):
    adCode: str
    kind: str

@typing.type_check_only
class AdStyle(typing_extensions.TypedDict, total=False):
    colors: dict[str, typing.Any]
    corners: str
    font: dict[str, typing.Any]
    kind: str

@typing.type_check_only
class AdUnit(typing_extensions.TypedDict, total=False):
    code: str
    contentAdsSettings: dict[str, typing.Any]
    customStyle: AdStyle
    id: str
    kind: str
    mobileContentAdsSettings: dict[str, typing.Any]
    name: str
    status: str

@typing.type_check_only
class AdUnits(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[AdUnit]
    kind: str
    nextPageToken: str

@typing.type_check_only
class AssociationSession(typing_extensions.TypedDict, total=False):
    accountId: str
    id: str
    kind: str
    productCodes: _list[str]
    redirectUrl: str
    status: str
    userLocale: str
    websiteLocale: str
    websiteUrl: str

@typing.type_check_only
class CustomChannel(typing_extensions.TypedDict, total=False):
    code: str
    id: str
    kind: str
    name: str

@typing.type_check_only
class CustomChannels(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[CustomChannel]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Report(typing_extensions.TypedDict, total=False):
    averages: _list[str]
    headers: _list[dict[str, typing.Any]]
    kind: str
    rows: _list[list]
    totalMatchedRows: str
    totals: _list[str]
    warnings: _list[str]

@typing.type_check_only
class UrlChannel(typing_extensions.TypedDict, total=False):
    id: str
    kind: str
    urlPattern: str

@typing.type_check_only
class UrlChannels(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[UrlChannel]
    kind: str
    nextPageToken: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AvroFileFormat(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class BackfillAllStrategy(typing_extensions.TypedDict, total=False):
    mysqlExcludedObjects: MysqlRdbms
    oracleExcludedObjects: OracleRdbms
    postgresqlExcludedObjects: PostgresqlRdbms

@typing.type_check_only
class BackfillJob(typing_extensions.TypedDict, total=False):
    errors: _list[Error]
    lastEndTime: str
    lastStartTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "NOT_STARTED",
        "PENDING",
        "ACTIVE",
        "STOPPED",
        "FAILED",
        "COMPLETED",
        "UNSUPPORTED",
    ]
    trigger: typing_extensions.Literal["TRIGGER_UNSPECIFIED", "AUTOMATIC", "MANUAL"]

@typing.type_check_only
class BackfillNoneStrategy(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class BigQueryDestinationConfig(typing_extensions.TypedDict, total=False):
    dataFreshness: str
    singleTargetDataset: SingleTargetDataset
    sourceHierarchyDatasets: SourceHierarchyDatasets

@typing.type_check_only
class BigQueryProfile(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ConnectionProfile(typing_extensions.TypedDict, total=False):
    bigqueryProfile: BigQueryProfile
    createTime: str
    displayName: str
    forwardSshConnectivity: ForwardSshTunnelConnectivity
    gcsProfile: GcsProfile
    labels: dict[str, typing.Any]
    mysqlProfile: MysqlProfile
    name: str
    oracleProfile: OracleProfile
    postgresqlProfile: PostgresqlProfile
    privateConnectivity: PrivateConnectivity
    staticServiceIpConnectivity: StaticServiceIpConnectivity
    updateTime: str

@typing.type_check_only
class DatasetTemplate(typing_extensions.TypedDict, total=False):
    datasetIdPrefix: str
    kmsKeyName: str
    location: str

@typing.type_check_only
class DestinationConfig(typing_extensions.TypedDict, total=False):
    bigqueryDestinationConfig: BigQueryDestinationConfig
    destinationConnectionProfile: str
    gcsDestinationConfig: GcsDestinationConfig

@typing.type_check_only
class DiscoverConnectionProfileRequest(typing_extensions.TypedDict, total=False):
    connectionProfile: ConnectionProfile
    connectionProfileName: str
    fullHierarchy: bool
    hierarchyDepth: int
    mysqlRdbms: MysqlRdbms
    oracleRdbms: OracleRdbms
    postgresqlRdbms: PostgresqlRdbms

@typing.type_check_only
class DiscoverConnectionProfileResponse(typing_extensions.TypedDict, total=False):
    mysqlRdbms: MysqlRdbms
    oracleRdbms: OracleRdbms
    postgresqlRdbms: PostgresqlRdbms

@typing.type_check_only
class DropLargeObjects(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Error(typing_extensions.TypedDict, total=False):
    details: dict[str, typing.Any]
    errorTime: str
    errorUuid: str
    message: str
    reason: str

@typing.type_check_only
class FetchStaticIpsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    staticIps: _list[str]

@typing.type_check_only
class ForwardSshTunnelConnectivity(typing_extensions.TypedDict, total=False):
    hostname: str
    password: str
    port: int
    privateKey: str
    username: str

@typing.type_check_only
class GcsDestinationConfig(typing_extensions.TypedDict, total=False):
    avroFileFormat: AvroFileFormat
    fileRotationInterval: str
    fileRotationMb: int
    jsonFileFormat: JsonFileFormat
    path: str

@typing.type_check_only
class GcsProfile(typing_extensions.TypedDict, total=False):
    bucket: str
    rootPath: str

@typing.type_check_only
class JsonFileFormat(typing_extensions.TypedDict, total=False):
    compression: typing_extensions.Literal[
        "JSON_COMPRESSION_UNSPECIFIED", "NO_COMPRESSION", "GZIP"
    ]
    schemaFileFormat: typing_extensions.Literal[
        "SCHEMA_FILE_FORMAT_UNSPECIFIED", "NO_SCHEMA_FILE", "AVRO_SCHEMA_FILE"
    ]

@typing.type_check_only
class ListConnectionProfilesResponse(typing_extensions.TypedDict, total=False):
    connectionProfiles: _list[ConnectionProfile]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListPrivateConnectionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    privateConnections: _list[PrivateConnection]
    unreachable: _list[str]

@typing.type_check_only
class ListRoutesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    routes: _list[Route]
    unreachable: _list[str]

@typing.type_check_only
class ListStreamObjectsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    streamObjects: _list[StreamObject]

@typing.type_check_only
class ListStreamsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    streams: _list[Stream]
    unreachable: _list[str]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class LookupStreamObjectRequest(typing_extensions.TypedDict, total=False):
    sourceObjectIdentifier: SourceObjectIdentifier

@typing.type_check_only
class MysqlColumn(typing_extensions.TypedDict, total=False):
    collation: str
    column: str
    dataType: str
    length: int
    nullable: bool
    ordinalPosition: int
    primaryKey: bool

@typing.type_check_only
class MysqlDatabase(typing_extensions.TypedDict, total=False):
    database: str
    mysqlTables: _list[MysqlTable]

@typing.type_check_only
class MysqlObjectIdentifier(typing_extensions.TypedDict, total=False):
    database: str
    table: str

@typing.type_check_only
class MysqlProfile(typing_extensions.TypedDict, total=False):
    hostname: str
    password: str
    port: int
    sslConfig: MysqlSslConfig
    username: str

@typing.type_check_only
class MysqlRdbms(typing_extensions.TypedDict, total=False):
    mysqlDatabases: _list[MysqlDatabase]

@typing.type_check_only
class MysqlSourceConfig(typing_extensions.TypedDict, total=False):
    excludeObjects: MysqlRdbms
    includeObjects: MysqlRdbms
    maxConcurrentCdcTasks: int

@typing.type_check_only
class MysqlSslConfig(typing_extensions.TypedDict, total=False):
    caCertificate: str
    caCertificateSet: bool
    clientCertificate: str
    clientCertificateSet: bool
    clientKey: str
    clientKeySet: bool

@typing.type_check_only
class MysqlTable(typing_extensions.TypedDict, total=False):
    mysqlColumns: _list[MysqlColumn]
    table: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    validationResult: ValidationResult
    verb: str

@typing.type_check_only
class OracleColumn(typing_extensions.TypedDict, total=False):
    column: str
    dataType: str
    encoding: str
    length: int
    nullable: bool
    ordinalPosition: int
    precision: int
    primaryKey: bool
    scale: int

@typing.type_check_only
class OracleObjectIdentifier(typing_extensions.TypedDict, total=False):
    schema: str
    table: str

@typing.type_check_only
class OracleProfile(typing_extensions.TypedDict, total=False):
    connectionAttributes: dict[str, typing.Any]
    databaseService: str
    hostname: str
    password: str
    port: int
    username: str

@typing.type_check_only
class OracleRdbms(typing_extensions.TypedDict, total=False):
    oracleSchemas: _list[OracleSchema]

@typing.type_check_only
class OracleSchema(typing_extensions.TypedDict, total=False):
    oracleTables: _list[OracleTable]
    schema: str

@typing.type_check_only
class OracleSourceConfig(typing_extensions.TypedDict, total=False):
    dropLargeObjects: DropLargeObjects
    excludeObjects: OracleRdbms
    includeObjects: OracleRdbms
    maxConcurrentCdcTasks: int
    streamLargeObjects: StreamLargeObjects

@typing.type_check_only
class OracleTable(typing_extensions.TypedDict, total=False):
    oracleColumns: _list[OracleColumn]
    table: str

@typing.type_check_only
class PostgresqlColumn(typing_extensions.TypedDict, total=False):
    column: str
    dataType: str
    length: int
    nullable: bool
    ordinalPosition: int
    precision: int
    primaryKey: bool
    scale: int

@typing.type_check_only
class PostgresqlObjectIdentifier(typing_extensions.TypedDict, total=False):
    schema: str
    table: str

@typing.type_check_only
class PostgresqlProfile(typing_extensions.TypedDict, total=False):
    database: str
    hostname: str
    password: str
    port: int
    username: str

@typing.type_check_only
class PostgresqlRdbms(typing_extensions.TypedDict, total=False):
    postgresqlSchemas: _list[PostgresqlSchema]

@typing.type_check_only
class PostgresqlSchema(typing_extensions.TypedDict, total=False):
    postgresqlTables: _list[PostgresqlTable]
    schema: str

@typing.type_check_only
class PostgresqlSourceConfig(typing_extensions.TypedDict, total=False):
    excludeObjects: PostgresqlRdbms
    includeObjects: PostgresqlRdbms
    publication: str
    replicationSlot: str

@typing.type_check_only
class PostgresqlTable(typing_extensions.TypedDict, total=False):
    postgresqlColumns: _list[PostgresqlColumn]
    table: str

@typing.type_check_only
class PrivateConnection(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    error: Error
    labels: dict[str, typing.Any]
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "CREATING",
        "CREATED",
        "FAILED",
        "DELETING",
        "FAILED_TO_DELETE",
    ]
    updateTime: str
    vpcPeeringConfig: VpcPeeringConfig

@typing.type_check_only
class PrivateConnectivity(typing_extensions.TypedDict, total=False):
    privateConnection: str

@typing.type_check_only
class Route(typing_extensions.TypedDict, total=False):
    createTime: str
    destinationAddress: str
    destinationPort: int
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    updateTime: str

@typing.type_check_only
class SingleTargetDataset(typing_extensions.TypedDict, total=False):
    datasetId: str

@typing.type_check_only
class SourceConfig(typing_extensions.TypedDict, total=False):
    mysqlSourceConfig: MysqlSourceConfig
    oracleSourceConfig: OracleSourceConfig
    postgresqlSourceConfig: PostgresqlSourceConfig
    sourceConnectionProfile: str

@typing.type_check_only
class SourceHierarchyDatasets(typing_extensions.TypedDict, total=False):
    datasetTemplate: DatasetTemplate

@typing.type_check_only
class SourceObjectIdentifier(typing_extensions.TypedDict, total=False):
    mysqlIdentifier: MysqlObjectIdentifier
    oracleIdentifier: OracleObjectIdentifier
    postgresqlIdentifier: PostgresqlObjectIdentifier

@typing.type_check_only
class StartBackfillJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class StartBackfillJobResponse(typing_extensions.TypedDict, total=False):
    object: StreamObject

@typing.type_check_only
class StaticServiceIpConnectivity(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StopBackfillJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class StopBackfillJobResponse(typing_extensions.TypedDict, total=False):
    object: StreamObject

@typing.type_check_only
class Stream(typing_extensions.TypedDict, total=False):
    backfillAll: BackfillAllStrategy
    backfillNone: BackfillNoneStrategy
    createTime: str
    customerManagedEncryptionKey: str
    destinationConfig: DestinationConfig
    displayName: str
    errors: _list[Error]
    labels: dict[str, typing.Any]
    name: str
    sourceConfig: SourceConfig
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "NOT_STARTED",
        "RUNNING",
        "PAUSED",
        "MAINTENANCE",
        "FAILED",
        "FAILED_PERMANENTLY",
        "STARTING",
        "DRAINING",
    ]
    updateTime: str

@typing.type_check_only
class StreamLargeObjects(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class StreamObject(typing_extensions.TypedDict, total=False):
    backfillJob: BackfillJob
    createTime: str
    displayName: str
    errors: _list[Error]
    name: str
    sourceObject: SourceObjectIdentifier
    updateTime: str

@typing.type_check_only
class Validation(typing_extensions.TypedDict, total=False):
    code: str
    description: str
    message: _list[ValidationMessage]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "NOT_EXECUTED", "FAILED", "PASSED"
    ]

@typing.type_check_only
class ValidationMessage(typing_extensions.TypedDict, total=False):
    code: str
    level: typing_extensions.Literal["LEVEL_UNSPECIFIED", "WARNING", "ERROR"]
    message: str
    metadata: dict[str, typing.Any]

@typing.type_check_only
class ValidationResult(typing_extensions.TypedDict, total=False):
    validations: _list[Validation]

@typing.type_check_only
class VpcPeeringConfig(typing_extensions.TypedDict, total=False):
    subnet: str
    vpc: str
